@@ -47,6 +47,8 @@
 #include "dbusnotifier.h"
 #endif
 
+#include "wayland/ScreenShot.h"
+
 Core* Core::corePtr = nullptr;
 
 Core::Core()
@@ -80,7 +82,11 @@ Core::Core()
     QCommandLineOption optRunMinimized(QStringList() << QStringLiteral("m") << QStringLiteral("minimized"), tr("Run the application with a hidden main window"));
     _cmdLine.addOption(optRunMinimized);
 
-    sleep(250);
+    QCommandLineOption optShowNoWin(QStringList() << QStringLiteral("n") << QStringLiteral("no-win"), tr("Save screenshot and exit, without showing window"));
+    _cmdLine.addOption(optShowNoWin);
+
+    if (QGuiApplication::platformName() != QStringLiteral("wayland"))
+        sleep(250);
 
     _wnd = nullptr;
 }
@@ -104,33 +110,24 @@ Core* Core::instance()
 Core::~Core()
 {
     killTempFile();
+    delete _selector;
     delete _pixelMap;
     _conf->killInstance();
 }
 
 void Core::initWindow(const QString& ipcMessage)
 {
-    if (!_wnd) {
+    if (!_wnd)
+    {
         _wnd = new MainWindow;
         _wnd->setConfig(_conf);
         _wnd->updateModulesActions(_modules.generateModulesActions());
         _wnd->updateModulesMenus(_modules.generateModulesMenus());
 
         screenShot(true); // first screenshot
-
-        _wnd->resize(_conf->getRestoredWndSize());
-
-        if (_wnd) {
-            if (runAsMinimized())
-            {
-                if (_wnd->isTrayed())
-                    _wnd->windowHideShow();
-                else
-                    _wnd->showMinimized();
-            } else
-                _wnd->show();
-        }
-    } else {
+    }
+    else
+    {
         _wnd->showWindow(ipcMessage);
         screenShot();
     }
@@ -147,13 +144,17 @@ void Core::sleep(int msec)
 
 void Core::coreQuit()
 {
+    if (_wnd && !_wnd->findChildren<QDialog*>().isEmpty())
+        return; // WARNING: quitting with a modal dialog causes crash
+
     _conf->setLastSelection(_lastSelectedArea);
     _conf->saveScreenshotSettings();
 
     if (_wnd) {
         _conf->setRestoredWndSize(_wnd->width(), _wnd->height());
         _conf->saveWndSize();
-        _wnd->close();
+        if (_wnd->isVisible())
+            _wnd->close();
     }
 
     if (corePtr)
@@ -165,15 +166,25 @@ void Core::coreQuit()
     qApp->quit();
 }
 
-void Core::setScreen()
+void Core::newScreenshot()
 {
     _wnd->hideToShot();
 
-    // new code experimental
     if (_conf->getDelay() == 0)
         QTimer::singleShot(200, this, SLOT(screenShot()));
     else
+    {
+        if (QGuiApplication::platformName() == QStringLiteral("wayland")
+            && (_conf->getDefScreenshotType() == Core::Area
+                || _conf->getDefScreenshotType() == Core::PreviousSelection))
+        {
+            // Since a Wayland area screenshot is taken on a transparent overlay,
+            // the delay should be applied after selecting the area.
+            screenShot(false, true);
+            return;
+        }
         QTimer::singleShot(1000 * _conf->getDelay(), this, SLOT(screenShot()));
+    }
 
 }
 
@@ -194,17 +205,33 @@ void Core::getFullScreenPixmap(QScreen* screen)
 }
 
 // get screenshot
-void Core::screenShot(bool first)
+void Core::screenShot(bool first, bool delayed)
 {
+    // WARNING: With a modal dialog, the mouse and keyboard can be blocked
+    // when an area screenshot is taken (e.g., by a global shortcut).
+    if (!_wnd->findChildren<QDialog*>().isEmpty()
+        && (_conf->getDefScreenshotType() == Core::Area
+            || _conf->getDefScreenshotType() == Core::PreviousSelection))
+    {
+        return;
+    }
+
     killTempFile(); // remove the old temp file if any
 
-    sleep(400); // delay for hide "fade effect" bug in the KWin with compositing
+    if (QGuiApplication::platformName() != QStringLiteral("wayland"))
+        sleep(400); // delay for hide "fade effect" bug in the KWin with compositing
     _firstScreen = first;
 
     // Update the last saving date, if this is the first screenshot
     if (_firstScreen)
         _conf->updateLastSaveDate();
 
+    if (QGuiApplication::platformName() == QStringLiteral("wayland"))
+    {
+        waylandScreenShot(delayed);
+        return;
+    }
+
     switch(_conf->getDefScreenshotType())
     {
     case Core::FullScreen:
@@ -215,15 +242,17 @@ void Core::screenShot(bool first)
         getFullScreenPixmap(screen);
         grabCursor(0, 0);
 
-        checkAutoSave(first);
+        checkAutoSave();
         _wnd->updatePixmap(_pixelMap);
+        showScreenshot();
         break;
     }
     case Core::Window:
     {
         getActiveWindow();
-        checkAutoSave(first);
+        checkAutoSave();
         _wnd->updatePixmap(_pixelMap);
+        showScreenshot();
         break;
     }
     case Core::Area:
@@ -240,21 +269,117 @@ void Core::screenShot(bool first)
     }
     default:
         getFullScreenPixmap(QGuiApplication::primaryScreen());
+        _wnd->updatePixmap(_pixelMap);
+        showScreenshot();
         break;
     }
-
-
-
-    _wnd->updatePixmap(_pixelMap);
-    _wnd->restoreFromShot();
 }
 
-void Core::checkAutoSave(bool first)
+// Should be called only on Wayland.
+void Core::waylandScreenShot(bool delayed)
 {
+    if (_selector != nullptr)
+        return; // an area screenshot is in progress
+
+    switch(_conf->getDefScreenshotType())
+    {
+    case Core::Area:
+        _selector = new RegionSelect(_conf, _wnd->selectedScreen());
+        [[fallthrough]];
+    case Core::PreviousSelection:
+    {
+        if (_selector == nullptr)
+            _selector = new RegionSelect(_conf, _lastSelectedArea, _wnd->selectedScreen());
+        connect(_selector, &RegionSelect::processDone, this, [this, delayed](bool grabbed) {
+            if (!grabbed)
+            {
+                _wnd->restoreFromShot();
+                _selector->deleteLater();
+                _selector = nullptr;
+                return;
+            }
+            _selector->hide();
+            if (delayed)
+                QTimer::singleShot(1000 * _conf->getDelay(), this, SLOT(takeWaylandAreaScreenshot()));
+            else
+                takeWaylandAreaScreenshot(false);
+        });
+        break;
+    }
+    default: // for now, we can take only a fullscreen shot
+    {
+        auto ws = new LXQt::Wayland::ScreenShot(_conf->getIncludeCursor(),
+                                                _wnd->selectedScreen(),
+                                                QRect(),
+                                                this);
+        connect(ws, &LXQt::Wayland::ScreenShot::screenShotReady, this,
+                [this, ws] (const QPixmap& pixmap) {
+            if (!pixmap.isNull())
+            {
+                *_pixelMap = pixmap;
+                checkAutoSave();
+                _wnd->updatePixmap(_pixelMap);
+            }
+            showScreenshot();
+            ws->deleteLater();
+        });
+        break;
+    }
+    }
+}
+
+void Core::takeWaylandAreaScreenshot(bool checkCursor)
+{
+    if (_selector == nullptr)
+        return;
+    auto ws = new LXQt::Wayland::ScreenShot(checkCursor ? _conf->getIncludeCursor() : false,
+                                            _wnd->selectedScreen(),
+                                            _selector->getSelectionRect(),
+                                            this);
+    connect(ws, &LXQt::Wayland::ScreenShot::screenShotReady, this,
+            [this, ws] (const QPixmap& pixmap) {
+        if (!pixmap.isNull())
+        {
+            *_pixelMap = pixmap;
+            checkAutoSave();
+            _wnd->updatePixmap(_pixelMap);
+        }
+        showScreenshot();
+        _lastSelectedArea = _selector->getSelectionRect();
+        _selector->deleteLater();
+        _selector = nullptr;
+        ws->deleteLater();
+    });
+}
+
+void Core::showScreenshot()
+{
+    if (noWin())
+    { // quit if no window should be shown
+        QTimer::singleShot(0, this, &Core::coreQuit);
+        return;
+    }
+    _wnd->resize(_conf->getRestoredWndSize()); // before showing, to center the window on X11
+    _wnd->restoreFromShot();
+    if (runAsMinimized())
+    {
+        if (_wnd->isTrayed())
+            _wnd->windowHideShow();
+        else
+            _wnd->showMinimized();
+    }
+}
+
+void Core::checkAutoSave()
+{
+    if (noWin())
+    { // always auto-save with no window
+        QTimer::singleShot(0, this, SLOT(autoSave()));
+        return;
+    }
     if (_conf->getAutoSave())
     {
-        // hack
-        if (first)
+        if (_firstScreen)
         {
             if (_conf->getAutoSaveFirst())
                 QTimer::singleShot(600, this, SLOT(autoSave()));
@@ -570,6 +695,13 @@ bool Core::runAsMinimized()
     return (_cmdLine.isSet(QStringLiteral("minimized")) || _cmdLine.isSet(QStringLiteral("m")));
 }
 
+bool Core::noWin()
+{
+    return (_firstScreen
+            && (_cmdLine.isSet(QStringLiteral("no-win"))
+                || _cmdLine.isSet(QStringLiteral("n"))));
+}
+
 void Core::autoSave()
 {
     QString format = _conf->getSaveFormat();
@@ -614,5 +746,11 @@ void Core::regionGrabbed(bool grabbed)
     }
 
     _wnd->updatePixmap(_pixelMap);
+    showScreenshot();
+
+    // The selector should be closed only after it is hidden; otherwise, with the "-m"
+    // command-line option, the app will exit because its last window will be closed.
+    _selector->hide();
     _selector->deleteLater();
+    _selector = nullptr;
 }
