@@ -64,9 +64,9 @@ class Core : public QObject
 
 public Q_SLOTS:
     void coreQuit();
-    void setScreen();
+    void newScreenshot();
 
-    void screenShot(bool first = false);
+    void screenShot(bool first = false, bool delayed = false);
     void autoSave();
 
 public:
@@ -103,6 +103,7 @@ public:
     void processCmdLineOpts(const QStringList& arguments);
 
     bool runAsMinimized();
+    bool noWin();
 
     QString getSaveFilePath(const QString &format);
     QString getDateTimeFileName();
@@ -115,15 +116,16 @@ private:
 
     static Core *corePtr;
 
-    void checkAutoSave(bool first = false);
+    void checkAutoSave();
 
     void getActiveWindow();
     void grabCursor(int offsetX, int offsetY);
     bool checkExsistFile(const QString &path);
     QString copyFileNameToCliipboard(QString file);
     void sendNotify(const StateNotifyMessage& message);
-
     void getFullScreenPixmap(QScreen* screen);
+    void showScreenshot();
+    void waylandScreenShot(bool delayed);
 
     QPixmap *_pixelMap; // pixel map
     RegionSelect *_selector; // region grabber widget
@@ -142,6 +144,7 @@ private:
 
 private Q_SLOTS:
     void regionGrabbed(bool grabbed);
+    void takeWaylandAreaScreenshot(bool checkCursor = true);
 
 };
 
