@@ -38,7 +38,6 @@ MainWindow::MainWindow(QWidget* parent) : QMainWindow(parent),
     _trayed = false;
 
     _trayIcon = nullptr;
-    _hideWnd = nullptr;
     _trayMenu = nullptr;
 
     // create actions menu
@@ -46,36 +45,25 @@ MainWindow::MainWindow(QWidget* parent) : QMainWindow(parent),
     actSave = new QAction(QIcon::fromTheme(QStringLiteral("document-save")), tr("Save"), this);
     actCopy = new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), tr("Copy"), this);
     actOptions = new QAction(QIcon::fromTheme(QStringLiteral("configure")), tr("Options"), this);
-    actHelp = new QAction(QIcon::fromTheme(QStringLiteral("system-help")), tr("Help"), this);
-    actAbout = new QAction(QIcon::fromTheme(QStringLiteral("system-about")), tr("About"), this);
+    actAbout = new QAction(QIcon::fromTheme(QStringLiteral("help-about")), tr("About"), this);
     actQuit = new QAction(QIcon::fromTheme(QStringLiteral("application-exit")), tr("Quit"), this);
 
     // connect actions to slots
     Core *c = Core::instance();
 
     connect(actQuit, &QAction::triggered, c, &Core::coreQuit);
-    connect(actNew, &QAction::triggered, c, &Core::setScreen);
+    connect(actNew, &QAction::triggered, c, &Core::newScreenshot);
     connect(actSave, &QAction::triggered, this, &MainWindow::saveScreen);
     connect(actCopy, &QAction::triggered, c, &Core::copyScreen);
     connect(actOptions, &QAction::triggered, this, &MainWindow::showOptions);
     connect(actAbout, &QAction::triggered, this, &MainWindow::showAbout);
-    connect(actHelp, &QAction::triggered, this, &MainWindow::showHelp);
 
     _ui->toolBar->addAction(actNew);
     _ui->toolBar->addAction(actSave);
     _ui->toolBar->addAction(actCopy);
     _ui->toolBar->addAction(actOptions);
     _ui->toolBar->addSeparator();
-    QMenu *menuInfo = new QMenu(this);
-    menuInfo->addAction(actHelp);
-    menuInfo->addAction(actAbout);
-    QToolButton *help = new QToolButton(this);
-    help->setText(tr("Help"));
-    help->setPopupMode(QToolButton::InstantPopup);
-    help->setIcon(QIcon::fromTheme(QStringLiteral("system-help")));
-    help->setMenu(menuInfo);
-
-    _ui->toolBar->addWidget(help);
+    _ui->toolBar->addAction(actAbout);
 
     QWidget* spacer = new QWidget();
     spacer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
@@ -83,24 +71,56 @@ MainWindow::MainWindow(QWidget* parent) : QMainWindow(parent),
 
     _ui->toolBar->addAction(actQuit);
 
-    void (QSpinBox::*delayChange)(int) = &QSpinBox::valueChanged;
-    connect(_ui->delayBox, delayChange, this, &MainWindow::delayBoxChange);
-    void (QComboBox::*typeScr)(int) = &QComboBox::currentIndexChanged;
-    connect(_ui->cbxTypeScr, typeScr, this, &MainWindow::typeScreenShotChange);
+    connect(_ui->delayBox, &QSpinBox::valueChanged, this, &MainWindow::delayBoxChange);
+    connect(_ui->cbxTypeScr, &QComboBox::currentIndexChanged, this, &MainWindow::typeScreenShotChange);
     connect(_ui->checkIncludeCursor, &QCheckBox::toggled, this, &MainWindow::checkIncludeCursor);
     connect(_ui->checkNoDecoration, &QCheckBox::toggled, this, &MainWindow::checkNoDecoration);
     connect(_ui->checkZommMouseArea, &QCheckBox::toggled, this, &MainWindow::checkZommMouseArea);
 
+    if (QGuiApplication::platformName() == QStringLiteral("wayland"))
+    {
+        // Wayland does not support window screenshot for now.
+        // WARNING: If window shot becomes possible, change this and all occurrences of
+        // _ui->cbxTypeScr->setCurrentIndex as well as MainWindow::typeScreenShotChange
+        // in this file.
+        _ui->cbxTypeScr->removeItem(1);
+
+        auto screens = QGuiApplication::screens();
+        if (screens.size() > 1)
+        {
+            // sort screens from left to right and top to bottom
+            std::sort(screens.begin(), screens.end(), [](QScreen *a1, QScreen *a2) {
+                QPoint p1(a1->geometry().topLeft());
+                QPoint p2(a2->geometry().topLeft());
+                return (qAbs(p1.x() - p2.x()) > qAbs(p1.y() - p2.y())
+                        ? p1.x() < p2.x() : p1.y() < p2.y());
+            });
+            for (const auto &screen : std::as_const(screens))
+                _ui-> cbxScr->addItem(screen->name());
+            _ui->cbxScr->setCurrentIndex(0);
+            connect(_ui->cbxScr, &QComboBox::currentTextChanged, this,
+                    [this] (const QString &text) {
+                _conf->setScreen(text);
+            });
+        }
+        else
+        {
+            _ui->labScr->hide();
+            _ui->cbxScr->hide();
+        }
+    }
+    else
+    {
+        _ui->labScr->hide();
+        _ui->cbxScr->hide();
+    }
+
     appIcon = QIcon::fromTheme (QStringLiteral("screengrab"));
     if (appIcon.isNull())
         appIcon = QIcon(QStringLiteral(":/res/img/logo.png"));
 
     setWindowIcon(appIcon);
 
-    auto screens = QGuiApplication::screens();
-    const QRect geometry = screens.isEmpty() ? QRect() : screens.at(0)->availableGeometry();
-    move(geometry.width() / 2 - width() / 2, geometry.height() / 2 - height() / 2);
-
     _ui->scrLabel->installEventFilter(this);
     _ui->delayBox->installEventFilter(this);
 }
@@ -124,29 +144,47 @@ void MainWindow::changeEvent(QEvent *e)
 
 void MainWindow::closeEvent(QCloseEvent *e)
 {
-    if (_conf->getCloseInTray() && _conf->getShowTrayIcon())
+    if (!Core::instance()->noWin() && _conf->getCloseInTray() && _conf->getShowTrayIcon())
     {
-        windowHideShow();
+        if (findChildren<QDialog*>().isEmpty()) // do not hide with a modal dialog
+            windowHideShow();
         e->ignore();
     }
     else
         actQuit->activate(QAction::Trigger);
 }
 
-// resize main window
-void MainWindow::resizeEvent(QResizeEvent *event)
+void MainWindow::fitPixmap()
 {
-    Q_UNUSED(event)
-    // get size dcreen pixel map
-    QSize scaleSize = Core::instance()->getPixmap()->size(); // get orig size pixmap
-
+    QSize scaleSize = Core::instance()->getPixmap()->size(); // orig pixmap size
     scaleSize.scale(_ui->scrLabel->contentsRect().size(), Qt::KeepAspectRatio);
-
     const QPixmap pixmap = _ui->scrLabel->pixmap(Qt::ReturnByValue);
     if (pixmap.isNull() || scaleSize != pixmap.size())
         updatePixmap(Core::instance()->getPixmap());
 }
 
+void MainWindow::resizeEvent(QResizeEvent *event)
+{
+    QMainWindow::resizeEvent(event);
+    fitPixmap();
+}
+
+void MainWindow::showEvent(QShowEvent *event)
+{
+    if (QGuiApplication::platformName() != QStringLiteral("wayland")
+        && !event->spontaneous())
+    { // center the window on X11
+        auto screen = QGuiApplication::screenAt(QCursor::pos());
+        if (screen == nullptr)
+            screen = QGuiApplication::primaryScreen();
+        const QRect geometry = screen ? screen->availableGeometry() : QRect();
+        move(geometry.x() + (geometry.width() - width()) / 2,
+             geometry.y() + (geometry.height() - height()) / 2);
+    }
+    QMainWindow::showEvent(event);
+    fitPixmap();
+}
+
 bool MainWindow::eventFilter(QObject* obj, QEvent* event)
 {
     if (obj == _ui->scrLabel)
@@ -213,6 +251,27 @@ void MainWindow::updateModulesMenus(const QList<QMenu *> &list)
     }
 }
 
+QScreen* MainWindow::selectedScreen() const
+{
+    auto screens = QGuiApplication::screens();
+    if (screens.isEmpty())
+        return qApp->primaryScreen();
+    if (screens.size() == 1)
+        return screens.at(0);
+    for (const auto &screen : std::as_const(screens))
+    {
+        if (_ui->cbxScr->currentText() == screen->name())
+            return screen;
+    }
+    std::sort(screens.begin(), screens.end(), [](QScreen *a1, QScreen *a2) {
+        QPoint p1(a1->geometry().topLeft());
+        QPoint p2(a2->geometry().topLeft());
+        return (qAbs(p1.x() - p2.x()) > qAbs(p1.y() - p2.y())
+                ? p1.x() < p2.x() : p1.y() < p2.y());
+    });
+    return screens.at(0);
+}
+
 void MainWindow::show()
 {
     if (!isVisible() && !_trayed)
@@ -241,31 +300,6 @@ void MainWindow::setConfig(Config *config)
     updateUI();
 }
 
-
-void MainWindow::showHelp()
-{
-    QString localeHelpFile;
-
-    localeHelpFile = QStringLiteral(SG_DOCDIR) + QStringLiteral("%1html%1") + Config::getSysLang()+QStringLiteral("%1index.html");
-    localeHelpFile = localeHelpFile.arg(QString(QDir::separator()));
-
-    if (!QFile::exists(localeHelpFile))
-    {
-        localeHelpFile = QStringLiteral(SG_DOCDIR) + QStringLiteral("%1html%1") + Config::getSysLang().section(QStringLiteral("_"), 0, 0)  + QStringLiteral("%1index.html");
-        localeHelpFile = localeHelpFile.arg(QString(QDir::separator()));
-
-        if (!QFile::exists(localeHelpFile))
-        {
-            localeHelpFile = QStringLiteral(SG_DOCDIR) + QStringLiteral("%1html%1en%1index.html");
-            localeHelpFile = localeHelpFile.arg(QString(QDir::separator()));
-        }
-    }
-
-    // open find localize or eng help help
-    QDesktopServices::openUrl(QUrl::fromLocalFile(localeHelpFile));
-}
-
-
 void MainWindow::showOptions()
 {
     ConfigDialog *options = new ConfigDialog(this);
@@ -291,6 +325,15 @@ void MainWindow::showOptions()
 
 void MainWindow::showAbout()
 {
+    const auto dialogs  = findChildren<QDialog*>();
+    for (const auto &dialog : dialogs)
+    {
+        if (dialog->objectName() == QStringLiteral("aboutDialog"))
+        {
+            return;
+        }
+    }
+
     AboutDialog *about = new AboutDialog(this);
 
     if (isMinimized())
@@ -338,7 +381,6 @@ void MainWindow::createTray()
     _trayMenu->addSeparator();
     _trayMenu->addAction(actOptions);
     _trayMenu->addSeparator();
-    _trayMenu->addAction(actHelp);
     _trayMenu->addAction(actAbout);
     _trayMenu->addSeparator();
     _trayMenu->addAction(actQuit);
@@ -385,11 +427,25 @@ void MainWindow::delayBoxChange(int delay)
 
 void MainWindow::typeScreenShotChange(int type)
 {
-    _conf->setDefScreenshotType(type);
-    // show/hide checkboxes according to the type
-    _ui->checkNoDecoration->setVisible(type == 1);
-    _ui->checkIncludeCursor->setVisible(type < 2);
-    _ui->checkZommMouseArea->setVisible(type >= 2);
+    if (QGuiApplication::platformName() == QStringLiteral("wayland"))
+    {
+        _ui->checkIncludeCursor->setVisible(true);
+        if (type == 0)
+            _conf->setDefScreenshotType(0); // fullscreen
+        else if (type < 3)
+            _conf->setDefScreenshotType(type + 1);
+        _ui->checkNoDecoration->hide();
+        _ui->checkZommMouseArea->hide();
+    }
+    else
+    {
+        if (type < 4)
+            _conf->setDefScreenshotType(type);
+        // show/hide checkboxes according to the type
+        _ui->checkNoDecoration->setVisible(type == 1);
+        _ui->checkIncludeCursor->setVisible(type < 2);
+        _ui->checkZommMouseArea->setVisible(type >= 2);
+    }
 }
 
 void MainWindow::checkIncludeCursor(bool include)
@@ -413,11 +469,33 @@ void MainWindow::updateUI()
     _ui->delayBox->setValue(_conf->getDelay());
 
     int type = _conf->getDefScreenshotType();
-    _ui->cbxTypeScr->setCurrentIndex(type);
-    // show/hide checkboxes according to the type
-    _ui->checkNoDecoration->setVisible(type == 1);
-    _ui->checkIncludeCursor->setVisible(type < 2);
-    _ui->checkZommMouseArea->setVisible(type >= 2);
+    if (QGuiApplication::platformName() == QStringLiteral("wayland"))
+    {
+        _ui->checkIncludeCursor->setVisible(true);
+        if (type < 2)
+        {
+            _ui->cbxTypeScr->setCurrentIndex(0);
+        }
+        else if (type < 4)
+            _ui->cbxTypeScr->setCurrentIndex(type - 1);
+        _ui->checkNoDecoration->hide();
+        _ui->checkZommMouseArea->hide();
+
+        // if the last screen should be remembered, set up the combo-box
+        if (_conf->getRemLastScreen())
+            _ui->cbxScr->setCurrentText(_conf->getScreen());
+        // if the screen of the config file does not exist, correct it
+        _conf->setScreen(_ui->cbxScr->currentText());
+    }
+    else
+    {
+        if (type < 4)
+            _ui->cbxTypeScr->setCurrentIndex(type);
+        // show/hide checkboxes according to the type
+        _ui->checkNoDecoration->setVisible(type == 1);
+        _ui->checkIncludeCursor->setVisible(type < 2);
+        _ui->checkZommMouseArea->setVisible(type >= 2);
+    }
 
     _ui->checkZommMouseArea->setChecked(_conf->getZoomAroundMouse());
     _ui->checkNoDecoration->setChecked(_conf->getNoDecoration());
@@ -425,8 +503,8 @@ void MainWindow::updateUI()
 
     updateShortcuts();
 
-    // create tray object
-    if (_conf->getShowTrayIcon() && !_trayIcon)
+    // create tray object, but not with the "-n" option
+    if (!Core::instance()->noWin() && _conf->getShowTrayIcon() && !_trayIcon)
         createTray();
 
     // kill tray object, if tray was disabled in the configuration dialog
@@ -439,8 +517,11 @@ void MainWindow::trayClick(QSystemTrayIcon::ActivationReason reason)
 {
     if (findChildren<QDialog*>().count() > 0)
     { // just activate the window when there's a dialog
-        activateWindow();
-        raise();
+        if (QGuiApplication::platformName() != QStringLiteral("wayland"))
+        {
+            activateWindow();
+            raise();
+        }
         return;
     }
     switch(reason)
@@ -461,7 +542,7 @@ void MainWindow::windowHideShow()
         showNormal();
         activateWindow();
     }
-    else
+    else if (findChildren<QDialog*>().isEmpty()) // do not hide with a modal dialog
     {
         actHideShow->setText(tr("Show"));
         showMinimized();
@@ -472,7 +553,7 @@ void MainWindow::windowHideShow()
 
 void MainWindow::hideToShot()
 {
-    if (_conf->getShowTrayIcon())
+    if (_trayIcon && _conf->getShowTrayIcon())
     {
         _trayIcon->blockSignals(true);
         disableTrayMenuActions(true);
@@ -487,14 +568,30 @@ void MainWindow::showWindow(const QString& str)
     QString typeNum = str[str.size() - 1];
     int type = typeNum.toInt();
 
-    // change type scrren in config & on main window
-    _ui->cbxTypeScr->setCurrentIndex(type);
-    typeScreenShotChange(type);
+    // change screenshot type in config & on main window
+    if (QGuiApplication::platformName() == QStringLiteral("wayland"))
+    {
+        if (type < 2)
+        {
+            _ui->cbxTypeScr->setCurrentIndex(0);
+            typeScreenShotChange(0);
+        }
+        else if (type < 4)
+        {
+            _ui->cbxTypeScr->setCurrentIndex(type - 1);
+            typeScreenShotChange(type - 1);
+        }
+    }
+    else if (type < 4)
+    {
+        _ui->cbxTypeScr->setCurrentIndex(type);
+        typeScreenShotChange(type);
+    }
 }
 
 void MainWindow::restoreFromShot()
 {
-    if (_conf->getShowTrayIcon())
+    if (_trayIcon && _conf->getShowTrayIcon())
     {
         _trayIcon->blockSignals(false);
         disableTrayMenuActions(false);
@@ -565,6 +662,5 @@ void MainWindow::updateShortcuts()
     actSave->setShortcut(_conf->shortcuts()->getShortcut(Config::shortcutSave));
     actCopy->setShortcut(_conf->shortcuts()->getShortcut(Config::shortcutCopy));
     actOptions->setShortcut(_conf->shortcuts()->getShortcut(Config::shortcutOptions));
-    actHelp->setShortcut(_conf->shortcuts()->getShortcut(Config::shortcutHelp));
     actQuit->setShortcut(_conf->shortcuts()->getShortcut(Config::shortcutClose));
 }
