@@ -4,191 +4,141 @@
 <context>
     <name>AboutDialog</name>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="41"/>
+        <location filename="../src/core/ui/about.cpp" line="40"/>
         <source>About</source>
         <translation>Sobre</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="42"/>
+        <location filename="../src/core/ui/about.cpp" line="41"/>
         <source>Thanks</source>
         <translation>Grazas</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="43"/>
+        <location filename="../src/core/ui/about.cpp" line="42"/>
         <source>Help us</source>
         <translation>Axúdenos</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="100"/>
+        <location filename="../src/core/ui/about.cpp" line="99"/>
         <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
         <translation>é unha aplicación multiplataforma para facer rapidamente capturas de pantalla do seu escritorio.</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="102"/>
+        <location filename="../src/core/ui/about.cpp" line="101"/>
         <source>It is a light and powerful application, written in Qt.</source>
         <translation>É unha aplicación lixeira e potente, escrita en Qt.</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="34"/>
+        <location filename="../src/core/ui/about.cpp" line="33"/>
         <source>using Qt %1</source>
         <translation>usando Qt % 1</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="105"/>
+        <location filename="../src/core/ui/about.cpp" line="104"/>
         <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
         <translation>Sitio web - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="108"/>
+        <location filename="../src/core/ui/about.cpp" line="107"/>
         <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
         <translation>Licenza baixo a &lt;a href=%1&gt;GPL v2&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="112"/>
+        <location filename="../src/core/ui/about.cpp" line="111"/>
         <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
         <translation>Dereitos de autoría &amp;copy; 2009-2013, Artem «DOOMer» Galichkin</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="119"/>
+        <location filename="../src/core/ui/about.cpp" line="113"/>
+        <source>Copyright &amp;copy; 2013-2025, LXQt team</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/core/ui/about.cpp" line="120"/>
         <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
         <translation>Pode unirse a nós e axudarnos se quixer. Isto é un convite se lle gusta esta aplicación.</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="122"/>
+        <location filename="../src/core/ui/about.cpp" line="123"/>
         <source>What you can do?</source>
         <translation>Que pode facer vostede?</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="125"/>
+        <location filename="../src/core/ui/about.cpp" line="126"/>
         <source>Translate ScreenGrab to other languages</source>
         <translation>Traducir ScreenGrab a outros idiomas</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="126"/>
+        <location filename="../src/core/ui/about.cpp" line="127"/>
         <source>Make suggestions for next releases</source>
         <translation>Facer suxestións para próximas versións</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="127"/>
+        <location filename="../src/core/ui/about.cpp" line="128"/>
         <source>Report bugs and issues</source>
         <translation>Informar de fallos e outras incidencias</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="130"/>
+        <location filename="../src/core/ui/about.cpp" line="131"/>
         <source>Bug tracker</source>
         <translation>Seguimento de erros</translation>
     </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="140"/>
-        <source>Translate:</source>
-        <translation>Tradución:</translation>
-    </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="142"/>
-        <source> Brazilian Portuguese translation</source>
-        <translation> Tradución ao portugués do Brasil</translation>
+        <source>Special thanks to:</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="143"/>
-        <source>Marcio Moraes</source>
-        <translation></translation>
+        <location filename="../src/core/ui/about.cpp" line="144"/>
+        <source>for creating ScreenGrab</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="145"/>
-        <source> Ukrainian translation</source>
-        <translation> Tradución ao ucraíno</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="146"/>
-        <source>Gennadi Motsyo</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="148"/>
-        <source> Spanish translation</source>
-        <translation> Tradución ao español</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="149"/>
-        <source>Burjans L García D</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="151"/>
-        <source> Italian translation</source>
-        <translation> Tradución ao italiano</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="155"/>
-        <source>Testing:</source>
-        <translation>Probas:</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="157"/>
-        <source>Dual monitor support and other in Linux</source>
-        <translation>Compatibilidade para monitor dobre e outros en Linux</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="158"/>
-        <source>Dual monitor support in Linux</source>
-        <translation>Compatibilidade para monitor dobre en Linux</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="159"/>
-        <source>win32-build [Windows XP and 7]</source>
-        <translation>Construción win32 [Windows XP e 7]</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="160"/>
-        <source>old win32-build [Windows Vista]</source>
-        <translation>Construción win32 antigo [Windows Vista]</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="161"/>
-        <source>win32-build [Windows 7]</source>
-        <translation>Construción win32 [Windows 7]</translation>
+        <source>for supporting wlr screencopy protocol</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="182"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="190"/>
         <source>Directory %1 does not exist. Do you want to create it?</source>
         <translation>Non existe o directorio %1. Quere crealo?</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="183"/>
-        <location filename="../src/core/ui/configwidget.cpp" line="271"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="191"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="280"/>
         <source>Warning</source>
         <translation>Aviso</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="259"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="268"/>
         <source>Select directory</source>
         <translation>Seleccione o directorio</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="270"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="279"/>
         <source>Do you want to reset the settings to the defaults?</source>
         <translation>Quere reiniciar os axustes predeterminados?</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="314"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="313"/>
         <source>Example: </source>
         <translation>Exemplo: </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="355"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="354"/>
         <source>This key is already used in ScreenGrab! Please select another.</source>
         <translation>Esta tecla xa está en uso por ScreenGrab! Seleccione outra.</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="373"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="372"/>
         <source>This key is not supported on your system!</source>
         <translation>Esta tecla non está admitida no seu sistema!</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="393"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="392"/>
         <source>Error</source>
         <translation>Erro</translation>
     </message>
@@ -196,57 +146,62 @@
 <context>
     <name>Core</name>
     <message>
-        <location filename="../src/core/core.cpp" line="64"/>
+        <location filename="../src/core/core.cpp" line="66"/>
         <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
         <translation>é unha aplicación multiplataforma para facer rapidamente capturas de pantalla do seu escritorio.</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="68"/>
+        <location filename="../src/core/core.cpp" line="70"/>
         <source>Take a fullscreen screenshot</source>
         <translation>Facer unha captura da pantalla completa</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="72"/>
+        <location filename="../src/core/core.cpp" line="74"/>
         <source>Take a screenshot of the active window</source>
         <translation>Facer unha captura da xanela activa</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="76"/>
+        <location filename="../src/core/core.cpp" line="78"/>
         <source>Take a screenshot of a selection of the screen</source>
         <translation>Facer unha captura dunha área da pantalla</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="80"/>
+        <location filename="../src/core/core.cpp" line="82"/>
         <source>Run the application with a hidden main window</source>
         <translation>Executar a aplicación coa xanela principal agochada</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="450"/>
+        <location filename="../src/core/core.cpp" line="85"/>
+        <source>Save screenshot and exit, without showing window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/core/core.cpp" line="575"/>
         <source>Saved</source>
         <translation>Gardado</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="450"/>
+        <location filename="../src/core/core.cpp" line="575"/>
         <source>Saved to </source>
         <translation>Gardado en </translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="472"/>
+        <location filename="../src/core/core.cpp" line="597"/>
         <source>Name of saved file is copied to the clipboard</source>
         <translation>O nome do ficheiro gardado copiase no portapapeis</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="478"/>
+        <location filename="../src/core/core.cpp" line="603"/>
         <source>Path to saved file is copied to the clipboard</source>
         <translation>A ruta ao ficheiro gardado copiase ao portapapeis</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="501"/>
+        <location filename="../src/core/core.cpp" line="626"/>
         <source>Copied</source>
         <translation>Copiado</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="501"/>
+        <location filename="../src/core/core.cpp" line="626"/>
         <source>Screenshot is copied to clipboard</source>
         <translation>A captura de pantalla copiase ao portapapeis</translation>
     </message>
@@ -259,139 +214,138 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="73"/>
+        <source>Screen:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/core/ui/mainwindow.ui" line="105"/>
         <source>Type:</source>
         <translation>Tipo:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="115"/>
         <source>Type of screenshot</source>
         <translation>Tipo de captura de pantalla</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="122"/>
         <source>Full screen</source>
         <translation>Pantalla completa</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="127"/>
         <source>Window</source>
         <translation>Xanela</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="132"/>
         <source>Screen area</source>
         <translation>Área da pantalla</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="137"/>
         <source>Last selected area</source>
         <translation>Última área seleccionada</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="167"/>
         <source>Delay:</source>
         <translation>Demora:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="180"/>
         <source>Delay in seconds before taking screenshot</source>
         <translation>Demora en segundos antes facer a captura de pantalla</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="183"/>
         <source>None</source>
         <translation>Ningunha</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="186"/>
         <source> sec</source>
         <translation> seg</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="245"/>
         <source>Zoom area around mouse</source>
         <translation>Ampliar a área arredor do rato</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="252"/>
         <source>No window decoration</source>
         <translation>Sen a decoración da xanela</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="259"/>
         <source>Include mouse pointer</source>
         <translation>Incluír o punteiro do rato</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="291"/>
         <source>toolBar</source>
         <translation>BarraDeFerramentas</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="44"/>
         <source>New</source>
         <translation>Nova</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
         <source>Save</source>
         <translation>Gardar</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
         <source>Options</source>
         <translation>Opcións</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
-        <location filename="../src/core/ui/mainwindow.cpp" line="73"/>
-        <source>Help</source>
-        <translation>Axuda</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="50"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
         <source>About</source>
         <translation>Sobre</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="51"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
         <source>Quit</source>
         <translation>Saír</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="315"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="358"/>
         <source>Screenshot </source>
         <translation>Captura de pantalla </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="319"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="362"/>
         <source>Double click to open screenshot in external default image viewer</source>
         <translation>Faga dobre clic para abrir a captura de pantalla no visor de imaxes externo predeterminado</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="328"/>
-        <location filename="../src/core/ui/mainwindow.cpp" line="459"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="371"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="540"/>
         <source>Hide</source>
         <translation>Agochar</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="466"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="547"/>
         <source>Show</source>
         <translation>Amosar</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="519"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="616"/>
         <source>%1 Files</source>
         <translation>%1 ficheiro(s)</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="541"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="638"/>
         <source>Save As...</source>
         <translation>Gardar como...</translation>
     </message>
@@ -399,7 +353,15 @@
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="../src/core/regionselect.cpp" line="175"/>
+        <location filename="../src/core/regionselect.cpp" line="148"/>
+        <source>Click and drag to draw a rectangle,
+double click or press Enter
+to take a screenshot,
+or press Escape to cancel.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/core/regionselect.cpp" line="245"/>
         <source>Click and drag to draw a rectangle,
 right click to fit to edges,
 double click or press Enter
@@ -410,7 +372,7 @@ dobre clic ou prema Intro para facer unha
 captura de pantalla.</translation>
     </message>
     <message>
-        <location filename="../src/core/regionselect.cpp" line="207"/>
+        <location filename="../src/core/regionselect.cpp" line="305"/>
         <source>%1 x %2 pixels </source>
         <translation>%1 x %2 píxeles </translation>
     </message>
@@ -445,244 +407,249 @@ captura de pantalla.</translation>
     <name>configwidget</name>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="26"/>
-        <location filename="../src/core/ui/configwidget.ui" line="568"/>
+        <location filename="../src/core/ui/configwidget.ui" line="536"/>
         <source>Options</source>
         <translation>Opcións</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="77"/>
+        <location filename="../src/core/ui/configwidget.ui" line="35"/>
         <source>Main</source>
         <translation>Principal</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="82"/>
+        <location filename="../src/core/ui/configwidget.ui" line="40"/>
         <source>Advanced</source>
         <translation>Avanzado</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="87"/>
+        <location filename="../src/core/ui/configwidget.ui" line="45"/>
         <source>System tray</source>
         <translation>Área de notificación</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="92"/>
+        <location filename="../src/core/ui/configwidget.ui" line="50"/>
         <source>Shortcuts</source>
         <translation>Atallos</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="116"/>
+        <location filename="../src/core/ui/configwidget.ui" line="74"/>
         <source>Default save directory</source>
         <translation>Directorio predeterminado onde gardar</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="122"/>
+        <location filename="../src/core/ui/configwidget.ui" line="80"/>
         <source>Path to default selection dir for saving</source>
         <translation>Ruta ao directorio seleccionado como predeterminado para gardar</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="135"/>
+        <location filename="../src/core/ui/configwidget.ui" line="93"/>
         <source>Browse filesystem</source>
         <translation>Examinar o sistema de ficheiros</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="138"/>
+        <location filename="../src/core/ui/configwidget.ui" line="96"/>
         <source>Browse</source>
         <translation>Examinar</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="148"/>
+        <location filename="../src/core/ui/configwidget.ui" line="106"/>
         <source>Default file</source>
         <translation>Ficheiro predeterminado</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="161"/>
+        <location filename="../src/core/ui/configwidget.ui" line="119"/>
         <source>Name:</source>
         <translation>Nome:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="168"/>
+        <location filename="../src/core/ui/configwidget.ui" line="126"/>
         <source>Default filename</source>
         <translation>Nome predeterminado do ficheiro</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="179"/>
+        <location filename="../src/core/ui/configwidget.ui" line="137"/>
         <source>Format</source>
         <translation>Formato</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="192"/>
+        <location filename="../src/core/ui/configwidget.ui" line="150"/>
         <source>Default saving image format</source>
         <translation>Formato predeterminado para gardar imaxes</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="211"/>
+        <location filename="../src/core/ui/configwidget.ui" line="169"/>
         <source>Copy file name to the clipboard when saving</source>
         <translation>Copiar o nome do ficheiro ao portapapeis ao gardar</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="225"/>
+        <location filename="../src/core/ui/configwidget.ui" line="183"/>
         <source>Do not copy</source>
         <translation>Non copiar nada</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="230"/>
+        <location filename="../src/core/ui/configwidget.ui" line="188"/>
         <source>Copy file name only</source>
         <translation>Copiar só o nome do ficheiro</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="235"/>
+        <location filename="../src/core/ui/configwidget.ui" line="193"/>
         <source>Copy full file path</source>
         <translation>Copiar a ruta completa do ficheiro</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="245"/>
+        <location filename="../src/core/ui/configwidget.ui" line="203"/>
         <source>Image quality</source>
         <translation>Calidade da imaxe</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="251"/>
+        <location filename="../src/core/ui/configwidget.ui" line="209"/>
         <source>Image quality (1 - small file, 100 - high quality)</source>
         <translation>Calidade da imaxe (1 - ficheiro pequeno, 100 - alta calidade)</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="316"/>
+        <location filename="../src/core/ui/configwidget.ui" line="274"/>
         <source>Inserting current date time into saved filename</source>
         <translation>Inserindo a data e hora actuais no nome do ficheiro gardado</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="319"/>
+        <location filename="../src/core/ui/configwidget.ui" line="277"/>
         <source>Insert current date and time in file name</source>
         <translation>Inserir a data e hora actuais no nome do ficheiro</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="328"/>
+        <location filename="../src/core/ui/configwidget.ui" line="286"/>
         <source>Template: </source>
         <translation>Modelo: </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="353"/>
+        <location filename="../src/core/ui/configwidget.ui" line="311"/>
         <source>Example: </source>
         <translation>Exemplo: </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="363"/>
+        <location filename="../src/core/ui/configwidget.ui" line="321"/>
         <source>Automatically saving screenshots in grabbing process</source>
         <translation>Gardar automaticamente as capturas de pantalla durante o proceso de captura</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="366"/>
+        <location filename="../src/core/ui/configwidget.ui" line="324"/>
         <source>Autosave screenshot</source>
         <translation>Gardar automaticamente a captura de pantalla</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="378"/>
+        <location filename="../src/core/ui/configwidget.ui" line="336"/>
         <source>Save first screenshot</source>
         <translation>Gardar a primeira captura de pantalla</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="387"/>
+        <location filename="../src/core/ui/configwidget.ui" line="345"/>
         <source>Allow run multiplies copy of ScreenGrab</source>
         <translation>Permitir a execución de múltiples copias do ScreenGrab</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="390"/>
+        <location filename="../src/core/ui/configwidget.ui" line="348"/>
         <source>Allow multiple instances of ScreenGrab</source>
         <translation>Permitir múltiples instancias do ScreenGrab</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="397"/>
+        <location filename="../src/core/ui/configwidget.ui" line="355"/>
         <source>Open in external viewer on double click</source>
         <translation>Abrir no visor externo ao facer dobre clic</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="400"/>
+        <location filename="../src/core/ui/configwidget.ui" line="358"/>
         <source>Enable external viewer</source>
         <translation>Activar o visor externo</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="407"/>
+        <location filename="../src/core/ui/configwidget.ui" line="365"/>
         <source>If this is unchecked, the selected area
 might become larger to fit to outer edges</source>
         <translation>Se non está marcado, a área seleccionada
 pode ser maior para adaptarse aos bordos exteriores</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="411"/>
+        <location filename="../src/core/ui/configwidget.ui" line="369"/>
         <source>Fit to edges inside selected area by right clicking</source>
         <translation>Axuste aos bordos da área seleccionada premendo co botón dereito</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="418"/>
+        <location filename="../src/core/ui/configwidget.ui" line="376"/>
+        <source>With multiple screens</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/core/ui/configwidget.ui" line="379"/>
+        <source>Remember last selected screen in next session</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/core/ui/configwidget.ui" line="386"/>
         <source>Notify on saving and copying</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="427"/>
+        <location filename="../src/core/ui/configwidget.ui" line="395"/>
         <source>Duration:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="494"/>
+        <location filename="../src/core/ui/configwidget.ui" line="462"/>
         <source>Show ScreenGrab in the system tray</source>
         <translation>Amosar o ScreenGrab na área de notificación</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="434"/>
+        <location filename="../src/core/ui/configwidget.ui" line="402"/>
         <source> sec</source>
         <translation> seg</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="501"/>
+        <location filename="../src/core/ui/configwidget.ui" line="469"/>
         <source>Minimize to tray on click close button</source>
         <translation>Minimizar na área de notificación ao premer no botón de peche</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="504"/>
+        <location filename="../src/core/ui/configwidget.ui" line="472"/>
         <source>Minimize to tray when closing</source>
         <translation>Minimizar na área de notificación ao pechar</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="543"/>
+        <location filename="../src/core/ui/configwidget.ui" line="511"/>
         <source>Action</source>
         <translation>Acción</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="548"/>
+        <location filename="../src/core/ui/configwidget.ui" line="516"/>
         <source>Shortcut</source>
         <translation>Atallo</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="553"/>
+        <location filename="../src/core/ui/configwidget.ui" line="521"/>
         <source>New screen</source>
         <translation>Pantalla nova</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="558"/>
+        <location filename="../src/core/ui/configwidget.ui" line="526"/>
         <source>Save screen</source>
         <translation>Gardar a pantalla</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="563"/>
+        <location filename="../src/core/ui/configwidget.ui" line="531"/>
         <source>Copy screen</source>
         <translation>Copiar a pantalla</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="573"/>
-        <source>Help</source>
-        <translation>Axuda</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/configwidget.ui" line="578"/>
+        <location filename="../src/core/ui/configwidget.ui" line="541"/>
         <source>Quit</source>
         <translation>Saír</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="588"/>
+        <location filename="../src/core/ui/configwidget.ui" line="551"/>
         <source>Selected shortcut:</source>
         <translation>Atallo seleccionado:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="595"/>
+        <location filename="../src/core/ui/configwidget.ui" line="558"/>
         <source>Not defined</source>
         <translation>Sen definir</translation>
     </message>
