@@ -4,191 +4,141 @@
 <context>
     <name>AboutDialog</name>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="41"/>
+        <location filename="../src/core/ui/about.cpp" line="40"/>
         <source>About</source>
         <translation>შესახებ</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="42"/>
+        <location filename="../src/core/ui/about.cpp" line="41"/>
         <source>Thanks</source>
         <translation>მადლობა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="43"/>
+        <location filename="../src/core/ui/about.cpp" line="42"/>
         <source>Help us</source>
         <translation>დაგვეხმარეთ</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="100"/>
+        <location filename="../src/core/ui/about.cpp" line="99"/>
         <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
         <translation>პლატფორმათაშორისი აპლიკაციაა თქვენი სამუშაო მაგიდის ეკრანის ანაბეჭდის ასაღებად.</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="102"/>
+        <location filename="../src/core/ui/about.cpp" line="101"/>
         <source>It is a light and powerful application, written in Qt.</source>
         <translation>მსუბუქი და მძლავრი აპლიკაცია. დაწერილია Qt-ში.</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="34"/>
+        <location filename="../src/core/ui/about.cpp" line="33"/>
         <source>using Qt %1</source>
         <translation>გამოიყენება: Qt %1</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="105"/>
+        <location filename="../src/core/ui/about.cpp" line="104"/>
         <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
         <translation>ვებგვერდი - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="108"/>
+        <location filename="../src/core/ui/about.cpp" line="107"/>
         <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
         <translation>ვრცელდება ლიცენზიით &lt;a href=%1&gt;GPL v2&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="112"/>
+        <location filename="../src/core/ui/about.cpp" line="111"/>
         <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
         <translation>საავტორო უფლებები &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="119"/>
+        <location filename="../src/core/ui/about.cpp" line="113"/>
+        <source>Copyright &amp;copy; 2013-2025, LXQt team</source>
+        <translation>საავტორო უფლებები დაცულია &amp;copy; 2013-2025, LXQt-ის გუნდი</translation>
+    </message>
+    <message>
+        <location filename="../src/core/ui/about.cpp" line="120"/>
         <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
         <translation>შეგიძლიათ, შემოგვიერთდეთ და დაგვეხმაროთ, თუ გნებავთ. ეს მოსაწვევია, თუ ეს აპლიკაცია მოგწონთ.</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="122"/>
+        <location filename="../src/core/ui/about.cpp" line="123"/>
         <source>What you can do?</source>
         <translation>რისი გაკეთება შეგიძლიათ?</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="125"/>
+        <location filename="../src/core/ui/about.cpp" line="126"/>
         <source>Translate ScreenGrab to other languages</source>
         <translation>ScreenGrab-ის თარგმნა სხვა ენებზე</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="126"/>
+        <location filename="../src/core/ui/about.cpp" line="127"/>
         <source>Make suggestions for next releases</source>
         <translation>მინიშნებების შექმნა შემდეგი რელიზებისთვის</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="127"/>
+        <location filename="../src/core/ui/about.cpp" line="128"/>
         <source>Report bugs and issues</source>
         <translation>მოგვწერეთ შეცდომების და პრობლემების შესახებ</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="130"/>
+        <location filename="../src/core/ui/about.cpp" line="131"/>
         <source>Bug tracker</source>
         <translation>შეცდომების სია</translation>
     </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="140"/>
-        <source>Translate:</source>
-        <translation>თარგმანი:</translation>
-    </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="142"/>
-        <source> Brazilian Portuguese translation</source>
-        <translation> თარგმანი ბრაზილიურ პორტუგალიურზე</translation>
+        <source>Special thanks to:</source>
+        <translation>განსაკუთრებული მადლობა:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="143"/>
-        <source>Marcio Moraes</source>
-        <translation>Marcio Moraes</translation>
+        <location filename="../src/core/ui/about.cpp" line="144"/>
+        <source>for creating ScreenGrab</source>
+        <translation>ScreenGrab-ის შექმნისთვის</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="145"/>
-        <source> Ukrainian translation</source>
-        <translation> უკრაინული თარგმანი</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="146"/>
-        <source>Gennadi Motsyo</source>
-        <translation>Gennadi Motsyo</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="148"/>
-        <source> Spanish translation</source>
-        <translation> ესპანური თარგმანი</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="149"/>
-        <source>Burjans L García D</source>
-        <translation>Burjans L García D</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="151"/>
-        <source> Italian translation</source>
-        <translation> იტალიური თარგმანი</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="155"/>
-        <source>Testing:</source>
-        <translation>შემოწმება:</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="157"/>
-        <source>Dual monitor support and other in Linux</source>
-        <translation>ორი ეკრანის და ა.შ. მხარდაჭერა ლინუქსში</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="158"/>
-        <source>Dual monitor support in Linux</source>
-        <translation>ორი ეკრანის მხარდაჭერა ლინუქსში</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="159"/>
-        <source>win32-build [Windows XP and 7]</source>
-        <translation>win32-build [Windows XP და 7]</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="160"/>
-        <source>old win32-build [Windows Vista]</source>
-        <translation>ძველი win32-build [Windows Vista]</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="161"/>
-        <source>win32-build [Windows 7]</source>
-        <translation>win32-build [Windows 7]</translation>
+        <source>for supporting wlr screencopy protocol</source>
+        <translation>wlr ეკრანის კოპირების პროტოკოლის მხარდაჭერისთვის</translation>
     </message>
 </context>
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="182"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="190"/>
         <source>Directory %1 does not exist. Do you want to create it?</source>
         <translation>საქაღალდე %1 არ არსებობს. გნებავთ, შექმნათ ის?</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="183"/>
-        <location filename="../src/core/ui/configwidget.cpp" line="271"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="191"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="280"/>
         <source>Warning</source>
         <translation>გაფრთხილება</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="259"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="268"/>
         <source>Select directory</source>
         <translation>უჯრის ამორჩევა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="270"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="279"/>
         <source>Do you want to reset the settings to the defaults?</source>
         <translation>გნებავთ, ჩამოყაროთ პარამეტრები ნაგულისხმევ მნიშვნელობებზე?</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="314"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="313"/>
         <source>Example: </source>
         <translation>მაგალითი: </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="355"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="354"/>
         <source>This key is already used in ScreenGrab! Please select another.</source>
         <translation>ეს ღილაკი უკვე გამოიყენება ScreenGrab-ში! სხვა აირჩიეთ.</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="373"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="372"/>
         <source>This key is not supported on your system!</source>
         <translation>ეს ღილაკი თქვენს სისტემაზე მხარდაჭერილი არაა!</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="393"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="392"/>
         <source>Error</source>
         <translation>შეცდომა</translation>
     </message>
@@ -196,57 +146,62 @@
 <context>
     <name>Core</name>
     <message>
-        <location filename="../src/core/core.cpp" line="64"/>
+        <location filename="../src/core/core.cpp" line="66"/>
         <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
         <translation>პლატფორმათაშორისი აპლიკაციაა თქვენი სამუშაო მაგიდის ეკრანის ანაბეჭდის ასაღებად.</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="68"/>
+        <location filename="../src/core/core.cpp" line="70"/>
         <source>Take a fullscreen screenshot</source>
         <translation>სრული ეკრანის ანაბეჭდის აღება</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="72"/>
+        <location filename="../src/core/core.cpp" line="74"/>
         <source>Take a screenshot of the active window</source>
         <translation>აიღეთ აქტიური ფანჯრის ეკრანის ანაბეჭდი</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="76"/>
+        <location filename="../src/core/core.cpp" line="78"/>
         <source>Take a screenshot of a selection of the screen</source>
         <translation>ეკრანის მონიშნული ადგილის ანაბეჭდის აღება</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="80"/>
+        <location filename="../src/core/core.cpp" line="82"/>
         <source>Run the application with a hidden main window</source>
         <translation>აპლიკაციის დამალული მთავარი ფანჯრით გაშვება</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="450"/>
+        <location filename="../src/core/core.cpp" line="85"/>
+        <source>Save screenshot and exit, without showing window</source>
+        <translation>ეკრანის ანაბეჭდის შექმნა და გასვლა ფანჯრის ჩვენების გარეშე</translation>
+    </message>
+    <message>
+        <location filename="../src/core/core.cpp" line="575"/>
         <source>Saved</source>
         <translation>შენახულია</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="450"/>
+        <location filename="../src/core/core.cpp" line="575"/>
         <source>Saved to </source>
         <translation>შენახულია სად </translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="472"/>
+        <location filename="../src/core/core.cpp" line="597"/>
         <source>Name of saved file is copied to the clipboard</source>
         <translation>შენახული ფაილის სახელი ბუფერში დაკოპირდება</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="478"/>
+        <location filename="../src/core/core.cpp" line="603"/>
         <source>Path to saved file is copied to the clipboard</source>
         <translation>შენახული ფაილის ბილიკი დაკოპირდა ბუფერში</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="501"/>
+        <location filename="../src/core/core.cpp" line="626"/>
         <source>Copied</source>
         <translation>დაკოპირდა</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="501"/>
+        <location filename="../src/core/core.cpp" line="626"/>
         <source>Screenshot is copied to clipboard</source>
         <translation>ეკრანის ანაბეჭდი დაკოპირდება ბუფერში</translation>
     </message>
@@ -259,139 +214,138 @@
         <translation>ScreenGrab</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="73"/>
+        <source>Screen:</source>
+        <translation>ეკრანი:</translation>
+    </message>
+    <message>
+        <location filename="../src/core/ui/mainwindow.ui" line="105"/>
         <source>Type:</source>
         <translation>ტიპი:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="115"/>
         <source>Type of screenshot</source>
         <translation>ეკრანის ანაბეჭდის ტიპი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="122"/>
         <source>Full screen</source>
         <translation>სულ ეკრანზე</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="127"/>
         <source>Window</source>
         <translation>ფანჯარა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="132"/>
         <source>Screen area</source>
         <translation>ეკრანის ალაგი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="137"/>
         <source>Last selected area</source>
         <translation>ბოლოს მონიშნული ალაგი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="167"/>
         <source>Delay:</source>
         <translation>დაყოვნება:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="180"/>
         <source>Delay in seconds before taking screenshot</source>
         <translation>დაყოვნება წამებში ეკრანის ანაბეჭდის აღებამდე</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="183"/>
         <source>None</source>
         <translation>არაფერი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="186"/>
         <source> sec</source>
         <translation> წმ</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="245"/>
         <source>Zoom area around mouse</source>
         <translation>თაგუნას კურსორის გარშემო ადგილის გადიდება</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="252"/>
         <source>No window decoration</source>
         <translation>ფანჯრების დეკორაციის გარეშე</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="259"/>
         <source>Include mouse pointer</source>
         <translation>თაგუნას კურსორის ჩათვლით</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="291"/>
         <source>toolBar</source>
         <translation>ხელსაწყოთა ზოლი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="44"/>
         <source>New</source>
         <translation>ახალი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
         <source>Save</source>
         <translation>შენახვა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
         <source>Copy</source>
         <translation>კოპირება</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
         <source>Options</source>
         <translation>მორგება</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
-        <location filename="../src/core/ui/mainwindow.cpp" line="73"/>
-        <source>Help</source>
-        <translation>დახმარება</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="50"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
         <source>About</source>
         <translation>შესახებ</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="51"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
         <source>Quit</source>
         <translation>გასვლა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="315"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="358"/>
         <source>Screenshot </source>
         <translation>ეკრანის ანაბეჭდი </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="319"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="362"/>
         <source>Double click to open screenshot in external default image viewer</source>
         <translation>ორმაგი წკაპი ეკრანის ანაბეჭდის გარე ნაგულისხმევ გამოსახულებების დამთვალიერებელში გახსნის</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="328"/>
-        <location filename="../src/core/ui/mainwindow.cpp" line="459"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="371"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="540"/>
         <source>Hide</source>
         <translation>დამალვა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="466"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="547"/>
         <source>Show</source>
         <translation>ჩვენება</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="519"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="616"/>
         <source>%1 Files</source>
         <translation>%1 ფაილი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="541"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="638"/>
         <source>Save As...</source>
         <translation>შეინახვა &amp;როგორც...</translation>
     </message>
@@ -399,7 +353,18 @@
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="../src/core/regionselect.cpp" line="175"/>
+        <location filename="../src/core/regionselect.cpp" line="148"/>
+        <source>Click and drag to draw a rectangle,
+double click or press Enter
+to take a screenshot,
+or press Escape to cancel.</source>
+        <translation>დააწკაპუნეთ და გადაათრიეთ, რომ დახატოთ მართკუთხედი.
+ორმაგი წკაპი ან ღილაკი Enter
+ეკრანის ანაბეჭდის ასაღებად,
+ან Escape გასაუქმებლად.</translation>
+    </message>
+    <message>
+        <location filename="../src/core/regionselect.cpp" line="245"/>
         <source>Click and drag to draw a rectangle,
 right click to fit to edges,
 double click or press Enter
@@ -410,7 +375,7 @@ to take a screenshot.</source>
 ეკრანის ანაბეჭდის ასაღებად.</translation>
     </message>
     <message>
-        <location filename="../src/core/regionselect.cpp" line="207"/>
+        <location filename="../src/core/regionselect.cpp" line="305"/>
         <source>%1 x %2 pixels </source>
         <translation>%1 x %2 პიქსელი </translation>
     </message>
@@ -445,244 +410,249 @@ to take a screenshot.</source>
     <name>configwidget</name>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="26"/>
-        <location filename="../src/core/ui/configwidget.ui" line="568"/>
+        <location filename="../src/core/ui/configwidget.ui" line="536"/>
         <source>Options</source>
         <translation>მორგება</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="77"/>
+        <location filename="../src/core/ui/configwidget.ui" line="35"/>
         <source>Main</source>
         <translation>მთავარი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="82"/>
+        <location filename="../src/core/ui/configwidget.ui" line="40"/>
         <source>Advanced</source>
         <translation>დამატებით</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="87"/>
+        <location filename="../src/core/ui/configwidget.ui" line="45"/>
         <source>System tray</source>
         <translation>სისტემის კუთხე</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="92"/>
+        <location filename="../src/core/ui/configwidget.ui" line="50"/>
         <source>Shortcuts</source>
         <translation>მალსახმობი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="116"/>
+        <location filename="../src/core/ui/configwidget.ui" line="74"/>
         <source>Default save directory</source>
         <translation>ნაგულისხმევი შენახვის საქაღალდე</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="122"/>
+        <location filename="../src/core/ui/configwidget.ui" line="80"/>
         <source>Path to default selection dir for saving</source>
         <translation>ნაგულისხმევი საქაღალდის ბილიკი ფაილების შესანახად</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="135"/>
+        <location filename="../src/core/ui/configwidget.ui" line="93"/>
         <source>Browse filesystem</source>
         <translation>ფაილური სისტემის დათვალიერება</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="138"/>
+        <location filename="../src/core/ui/configwidget.ui" line="96"/>
         <source>Browse</source>
         <translation>პოვნა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="148"/>
+        <location filename="../src/core/ui/configwidget.ui" line="106"/>
         <source>Default file</source>
         <translation>ნაგულისხმევი ფაილი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="161"/>
+        <location filename="../src/core/ui/configwidget.ui" line="119"/>
         <source>Name:</source>
         <translation>სახელი:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="168"/>
+        <location filename="../src/core/ui/configwidget.ui" line="126"/>
         <source>Default filename</source>
         <translation>ნაგულისხმები ფაილის სახელი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="179"/>
+        <location filename="../src/core/ui/configwidget.ui" line="137"/>
         <source>Format</source>
         <translation>ფორმატი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="192"/>
+        <location filename="../src/core/ui/configwidget.ui" line="150"/>
         <source>Default saving image format</source>
         <translation>ნაგულისხმევი გამოსახულების ფორმატი შენახვისას</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="211"/>
+        <location filename="../src/core/ui/configwidget.ui" line="169"/>
         <source>Copy file name to the clipboard when saving</source>
         <translation>ფაილის სახელის დაკოპირება ბუფერში შენახვის შემდეგ</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="225"/>
+        <location filename="../src/core/ui/configwidget.ui" line="183"/>
         <source>Do not copy</source>
         <translation>არ დააკოპირო</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="230"/>
+        <location filename="../src/core/ui/configwidget.ui" line="188"/>
         <source>Copy file name only</source>
         <translation>მხოლოდ, ფაილის სახელის დაკოპირება</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="235"/>
+        <location filename="../src/core/ui/configwidget.ui" line="193"/>
         <source>Copy full file path</source>
         <translation>ფაილის სრული ბილიკის კოპირება</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="245"/>
+        <location filename="../src/core/ui/configwidget.ui" line="203"/>
         <source>Image quality</source>
         <translation>გამოსახულების ხარისხი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="251"/>
+        <location filename="../src/core/ui/configwidget.ui" line="209"/>
         <source>Image quality (1 - small file, 100 - high quality)</source>
         <translation>გამოსახულების ხარისხი (1 - პატარა ფაილი, 100 - მაღალი ხარისხი)</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="316"/>
+        <location filename="../src/core/ui/configwidget.ui" line="274"/>
         <source>Inserting current date time into saved filename</source>
         <translation>მიმდინარე დროისა და თარიღის ჩასმა შენახული ფაილიოს სახელში</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="319"/>
+        <location filename="../src/core/ui/configwidget.ui" line="277"/>
         <source>Insert current date and time in file name</source>
         <translation>მიმდინარე თარიღისა და დროის ჩასმა ფაილის სახელში</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="328"/>
+        <location filename="../src/core/ui/configwidget.ui" line="286"/>
         <source>Template: </source>
         <translation>შაბლონი: </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="353"/>
+        <location filename="../src/core/ui/configwidget.ui" line="311"/>
         <source>Example: </source>
         <translation>მაგალითი: </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="363"/>
+        <location filename="../src/core/ui/configwidget.ui" line="321"/>
         <source>Automatically saving screenshots in grabbing process</source>
         <translation>ეკრანის ანაბეჭდების ავტომატური შენახვა გადაღების პროცესში</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="366"/>
+        <location filename="../src/core/ui/configwidget.ui" line="324"/>
         <source>Autosave screenshot</source>
         <translation>ეკრანის ანაბეჭდის ავტოშენახვა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="378"/>
+        <location filename="../src/core/ui/configwidget.ui" line="336"/>
         <source>Save first screenshot</source>
         <translation>პირველი ეკრანის ანაბეჭდის შენახვა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="387"/>
+        <location filename="../src/core/ui/configwidget.ui" line="345"/>
         <source>Allow run multiplies copy of ScreenGrab</source>
         <translation>ScreenGrab-ის ერთზე მეტი გაშვებული ასლის ქონის უფლება</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="390"/>
+        <location filename="../src/core/ui/configwidget.ui" line="348"/>
         <source>Allow multiple instances of ScreenGrab</source>
         <translation>ScreeGrab-ის ერთზე მეტი გაშვებული ასლის ქონის დაშვება</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="397"/>
+        <location filename="../src/core/ui/configwidget.ui" line="355"/>
         <source>Open in external viewer on double click</source>
         <translation>ორმაგი წკაპისას გარე დამთვალიერებელში გახსნა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="400"/>
+        <location filename="../src/core/ui/configwidget.ui" line="358"/>
         <source>Enable external viewer</source>
         <translation>გარე დამთვალიერებლის ჩართვა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="407"/>
+        <location filename="../src/core/ui/configwidget.ui" line="365"/>
         <source>If this is unchecked, the selected area
 might become larger to fit to outer edges</source>
         <translation>თუ ეს გამორთულია, მონიშნული ალაგი,
 შეიძლება, გადიდდეს, რომ გარე წიბოებში ჩაეტიოს</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="411"/>
+        <location filename="../src/core/ui/configwidget.ui" line="369"/>
         <source>Fit to edges inside selected area by right clicking</source>
         <translation>მონიშნული ადგილის წიბოებში ჩატევა მარჯვენა წკაპით</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="418"/>
+        <location filename="../src/core/ui/configwidget.ui" line="376"/>
+        <source>With multiple screens</source>
+        <translation>ერთზე მეტი ეკრანით</translation>
+    </message>
+    <message>
+        <location filename="../src/core/ui/configwidget.ui" line="379"/>
+        <source>Remember last selected screen in next session</source>
+        <translation>ბოლოს არჩეული ეკრანის დამახსოვრება შემდეგ სესიაში</translation>
+    </message>
+    <message>
+        <location filename="../src/core/ui/configwidget.ui" line="386"/>
         <source>Notify on saving and copying</source>
         <translation>გაფრთხილება შენახვისა და კოპირებისას</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="427"/>
+        <location filename="../src/core/ui/configwidget.ui" line="395"/>
         <source>Duration:</source>
         <translation>ხანგრძლივობა:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="494"/>
+        <location filename="../src/core/ui/configwidget.ui" line="462"/>
         <source>Show ScreenGrab in the system tray</source>
         <translation>ScreenGrab-ის ჩვენება სისტემურ საათთან</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="434"/>
+        <location filename="../src/core/ui/configwidget.ui" line="402"/>
         <source> sec</source>
         <translation> წმ</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="501"/>
+        <location filename="../src/core/ui/configwidget.ui" line="469"/>
         <source>Minimize to tray on click close button</source>
         <translation>დახურვის ღილაკით სისტემურ საათთან ჩაკეცვა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="504"/>
+        <location filename="../src/core/ui/configwidget.ui" line="472"/>
         <source>Minimize to tray when closing</source>
         <translation>სისტემურ საათთან ჩაკეცვა დახურვისას</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="543"/>
+        <location filename="../src/core/ui/configwidget.ui" line="511"/>
         <source>Action</source>
         <translation>პარამეტრები</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="548"/>
+        <location filename="../src/core/ui/configwidget.ui" line="516"/>
         <source>Shortcut</source>
         <translation>მალმხმობი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="553"/>
+        <location filename="../src/core/ui/configwidget.ui" line="521"/>
         <source>New screen</source>
         <translation>ახალი ეკრანის ანაბეჭდი</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="558"/>
+        <location filename="../src/core/ui/configwidget.ui" line="526"/>
         <source>Save screen</source>
         <translation>ეკრანის ანაბეჭდის შენახვა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="563"/>
+        <location filename="../src/core/ui/configwidget.ui" line="531"/>
         <source>Copy screen</source>
         <translation>ეკრანის ანაბეჭდის კოპირება</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="573"/>
-        <source>Help</source>
-        <translation>დახმარება</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/configwidget.ui" line="578"/>
+        <location filename="../src/core/ui/configwidget.ui" line="541"/>
         <source>Quit</source>
         <translation>გასვლა</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="588"/>
+        <location filename="../src/core/ui/configwidget.ui" line="551"/>
         <source>Selected shortcut:</source>
         <translation>არჩეული მალსახმობი:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="595"/>
+        <location filename="../src/core/ui/configwidget.ui" line="558"/>
         <source>Not defined</source>
         <translation>აღუწერელია</translation>
     </message>
