@@ -4,191 +4,141 @@
 <context>
     <name>AboutDialog</name>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="41"/>
+        <location filename="../src/core/ui/about.cpp" line="40"/>
         <source>About</source>
         <translation>O programie</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="42"/>
+        <location filename="../src/core/ui/about.cpp" line="41"/>
         <source>Thanks</source>
         <translation>Podziękowania</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="43"/>
+        <location filename="../src/core/ui/about.cpp" line="42"/>
         <source>Help us</source>
         <translation>Pomóż nam</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="100"/>
+        <location filename="../src/core/ui/about.cpp" line="99"/>
         <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
         <translation>jest wieloplatformowym programem do szybkiego tworzenia zrzutów ekranu.</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="102"/>
+        <location filename="../src/core/ui/about.cpp" line="101"/>
         <source>It is a light and powerful application, written in Qt.</source>
         <translation>Jest to lekki i funkcjonalny program napisany w Qt.</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="34"/>
+        <location filename="../src/core/ui/about.cpp" line="33"/>
         <source>using Qt %1</source>
         <translation>używa Qt %1</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="105"/>
+        <location filename="../src/core/ui/about.cpp" line="104"/>
         <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
         <translation>Strona internetowa - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="108"/>
+        <location filename="../src/core/ui/about.cpp" line="107"/>
         <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
         <translation>Wydane na licencji &lt;a href=%1&gt;GPL v2&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="112"/>
+        <location filename="../src/core/ui/about.cpp" line="111"/>
         <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
         <translation>Prawa autorskie &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="119"/>
+        <location filename="../src/core/ui/about.cpp" line="113"/>
+        <source>Copyright &amp;copy; 2013-2025, LXQt team</source>
+        <translation>Prawa autorskie &amp;copy; 2013-2025, zespół LXQt</translation>
+    </message>
+    <message>
+        <location filename="../src/core/ui/about.cpp" line="120"/>
         <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
         <translation>Możesz dołączyć do nas i pomóc nam, jeśli chcesz i lubisz ten program.</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="122"/>
+        <location filename="../src/core/ui/about.cpp" line="123"/>
         <source>What you can do?</source>
         <translation>Co możesz zrobić?</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="125"/>
+        <location filename="../src/core/ui/about.cpp" line="126"/>
         <source>Translate ScreenGrab to other languages</source>
         <translation>Przetłumacz ScreenGrab na inne języki</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="126"/>
+        <location filename="../src/core/ui/about.cpp" line="127"/>
         <source>Make suggestions for next releases</source>
         <translation>Podziel się sugestiami na następne wydanie</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="127"/>
+        <location filename="../src/core/ui/about.cpp" line="128"/>
         <source>Report bugs and issues</source>
         <translation>Zgłoś błędy i problemy</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="130"/>
+        <location filename="../src/core/ui/about.cpp" line="131"/>
         <source>Bug tracker</source>
         <translation>Śledzenie błędów</translation>
     </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="140"/>
-        <source>Translate:</source>
-        <translation>Tłumaczenie:</translation>
-    </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="142"/>
-        <source> Brazilian Portuguese translation</source>
-        <translation> Tłumaczenie na brazylijski portugalski</translation>
+        <source>Special thanks to:</source>
+        <translation>Szczególne podziękowania dla:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/about.cpp" line="143"/>
-        <source>Marcio Moraes</source>
-        <translation></translation>
+        <location filename="../src/core/ui/about.cpp" line="144"/>
+        <source>for creating ScreenGrab</source>
+        <translation>za tworzenie ScreenGraba</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="145"/>
-        <source> Ukrainian translation</source>
-        <translation> Tłumaczenie ukraińskie</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="146"/>
-        <source>Gennadi Motsyo</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="148"/>
-        <source> Spanish translation</source>
-        <translation> Tłumaczenie hiszpańskie</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="149"/>
-        <source>Burjans L García D</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="151"/>
-        <source> Italian translation</source>
-        <translation> Tłumaczenie włoskie</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="155"/>
-        <source>Testing:</source>
-        <translation>Testowanie:</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="157"/>
-        <source>Dual monitor support and other in Linux</source>
-        <translation>Wsparcie wielu monitorów i inne na Linuksie</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="158"/>
-        <source>Dual monitor support in Linux</source>
-        <translation>Wsparcie dwóch monitorów na Linuksie</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="159"/>
-        <source>win32-build [Windows XP and 7]</source>
-        <translation>win32-build [Windows XP i 7]</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="160"/>
-        <source>old win32-build [Windows Vista]</source>
-        <translation>stary win32-build [Windows Vista]</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/about.cpp" line="161"/>
-        <source>win32-build [Windows 7]</source>
-        <translation></translation>
+        <source>for supporting wlr screencopy protocol</source>
+        <translation>za obsługę protokołu kopii ekranu wlr</translation>
     </message>
 </context>
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="182"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="190"/>
         <source>Directory %1 does not exist. Do you want to create it?</source>
         <translation>Ścieżka %1 nie istnieje. Czy chcesz ją utworzyć?</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="183"/>
-        <location filename="../src/core/ui/configwidget.cpp" line="271"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="191"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="280"/>
         <source>Warning</source>
         <translation>Ostrzeżenie</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="259"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="268"/>
         <source>Select directory</source>
         <translation>Wybierz położenie</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="270"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="279"/>
         <source>Do you want to reset the settings to the defaults?</source>
         <translation>Czy na pewno chcesz przywrócić ustawienia do domyślnych?</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="314"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="313"/>
         <source>Example: </source>
         <translation>Przykład: </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="355"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="354"/>
         <source>This key is already used in ScreenGrab! Please select another.</source>
         <translation>Ten klucz jest już używany przez ScreenGrab! Wybierz inny.</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="373"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="372"/>
         <source>This key is not supported on your system!</source>
         <translation>Ten klucz nie jest obsługiwany przez Twój system!</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.cpp" line="393"/>
+        <location filename="../src/core/ui/configwidget.cpp" line="392"/>
         <source>Error</source>
         <translation>Błąd</translation>
     </message>
@@ -196,57 +146,62 @@
 <context>
     <name>Core</name>
     <message>
-        <location filename="../src/core/core.cpp" line="64"/>
+        <location filename="../src/core/core.cpp" line="66"/>
         <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
         <translation>jest wieloplatformowym programem do szybkiego tworzenia zrzutów ekranu pulpitu.</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="68"/>
+        <location filename="../src/core/core.cpp" line="70"/>
         <source>Take a fullscreen screenshot</source>
         <translation>Zrób zrzut pełnego ekranu</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="72"/>
+        <location filename="../src/core/core.cpp" line="74"/>
         <source>Take a screenshot of the active window</source>
         <translation>Zrób zrzut ekranu aktywnego okna</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="76"/>
+        <location filename="../src/core/core.cpp" line="78"/>
         <source>Take a screenshot of a selection of the screen</source>
         <translation>Zrób zrzut zaznaczonego obszaru ekranu</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="80"/>
+        <location filename="../src/core/core.cpp" line="82"/>
         <source>Run the application with a hidden main window</source>
         <translation>Uruchom program z ukrytym głównym oknem</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="450"/>
+        <location filename="../src/core/core.cpp" line="85"/>
+        <source>Save screenshot and exit, without showing window</source>
+        <translation>Zapisz zrzut ekranu i wyjdź bez pokazywania okna</translation>
+    </message>
+    <message>
+        <location filename="../src/core/core.cpp" line="575"/>
         <source>Saved</source>
         <translation>Zapisano</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="450"/>
+        <location filename="../src/core/core.cpp" line="575"/>
         <source>Saved to </source>
         <translation>Zapisano do </translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="472"/>
+        <location filename="../src/core/core.cpp" line="597"/>
         <source>Name of saved file is copied to the clipboard</source>
         <translation>Nazwa zapisanego pliku została skopiowana do schowka</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="478"/>
+        <location filename="../src/core/core.cpp" line="603"/>
         <source>Path to saved file is copied to the clipboard</source>
         <translation>Ścieżka zapisanego pliku została skopiowana do schowka</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="501"/>
+        <location filename="../src/core/core.cpp" line="626"/>
         <source>Copied</source>
         <translation>Skopiowano</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="501"/>
+        <location filename="../src/core/core.cpp" line="626"/>
         <source>Screenshot is copied to clipboard</source>
         <translation>Zrzut ekranu został skopiowany do schowka</translation>
     </message>
@@ -259,139 +214,138 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="73"/>
+        <source>Screen:</source>
+        <translation>Ekran:</translation>
+    </message>
+    <message>
+        <location filename="../src/core/ui/mainwindow.ui" line="105"/>
         <source>Type:</source>
         <translation>Rodzaj:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="115"/>
         <source>Type of screenshot</source>
         <translation>Rodzaj zrzutu ekranu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="122"/>
         <source>Full screen</source>
         <translation>Pełny ekran</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="127"/>
         <source>Window</source>
         <translation>Okno</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="132"/>
         <source>Screen area</source>
         <translation>Fragment ekranu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="137"/>
         <source>Last selected area</source>
         <translation>Ostatnio zaznaczony obszar</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="167"/>
         <source>Delay:</source>
         <translation>Opóźnienie:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="180"/>
         <source>Delay in seconds before taking screenshot</source>
         <translation>Opóźnienie w sekundach przed wykonaniem zrzutu ekranu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="183"/>
         <source>None</source>
         <translation>Brak</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="186"/>
         <source> sec</source>
         <translation> s</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="245"/>
         <source>Zoom area around mouse</source>
         <translation>Powiększ obszar przy kursorze</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="252"/>
         <source>No window decoration</source>
         <translation>Bez dekoracji okna</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="259"/>
         <source>Include mouse pointer</source>
         <translation>Uwzględnij wskaźnik myszy</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
+        <location filename="../src/core/ui/mainwindow.ui" line="291"/>
         <source>toolBar</source>
         <translation>pasek narzędzi</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="44"/>
         <source>New</source>
         <translation>Nowy</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
         <source>Save</source>
         <translation>Zapisz</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
         <source>Copy</source>
         <translation>Kopiuj</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
         <source>Options</source>
         <translation>Opcje</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
-        <location filename="../src/core/ui/mainwindow.cpp" line="73"/>
-        <source>Help</source>
-        <translation>Pomoc</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="50"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
         <source>About</source>
         <translation>O programie</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="51"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
         <source>Quit</source>
         <translation>Wyjdź</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="315"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="358"/>
         <source>Screenshot </source>
         <translation>Zrzut ekranu </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="319"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="362"/>
         <source>Double click to open screenshot in external default image viewer</source>
         <translation>Kliknij dwukrotnie, aby otworzyć zrzut ekranu w zewnętrznej domyślnej przeglądarce obrazów</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="328"/>
-        <location filename="../src/core/ui/mainwindow.cpp" line="459"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="371"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="540"/>
         <source>Hide</source>
         <translation>Ukryj</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="466"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="547"/>
         <source>Show</source>
         <translation>Pokaż</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="519"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="616"/>
         <source>%1 Files</source>
         <translation>%1 plików</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="541"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="638"/>
         <source>Save As...</source>
         <translation>Zapisz jako…</translation>
     </message>
@@ -399,7 +353,18 @@
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="../src/core/regionselect.cpp" line="175"/>
+        <location filename="../src/core/regionselect.cpp" line="148"/>
+        <source>Click and drag to draw a rectangle,
+double click or press Enter
+to take a screenshot,
+or press Escape to cancel.</source>
+        <translation>Kliknij i przeciągnij, aby narysować prostokąt,
+kliknij dwukrotnie lub naciśnij Enter,
+aby wykonać zrzut ekranu,
+lub naciśnij Escape, aby anulować.</translation>
+    </message>
+    <message>
+        <location filename="../src/core/regionselect.cpp" line="245"/>
         <source>Click and drag to draw a rectangle,
 right click to fit to edges,
 double click or press Enter
@@ -410,7 +375,7 @@ kliknij dwukrotnie lub wciśnij Enter,
 aby wykonać zrzut ekranu.</translation>
     </message>
     <message>
-        <location filename="../src/core/regionselect.cpp" line="207"/>
+        <location filename="../src/core/regionselect.cpp" line="305"/>
         <source>%1 x %2 pixels </source>
         <translation>%1 x %2 pikseli </translation>
     </message>
@@ -445,244 +410,249 @@ aby wykonać zrzut ekranu.</translation>
     <name>configwidget</name>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="26"/>
-        <location filename="../src/core/ui/configwidget.ui" line="568"/>
+        <location filename="../src/core/ui/configwidget.ui" line="536"/>
         <source>Options</source>
         <translation>Opcje</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="77"/>
+        <location filename="../src/core/ui/configwidget.ui" line="35"/>
         <source>Main</source>
         <translation>Główne</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="82"/>
+        <location filename="../src/core/ui/configwidget.ui" line="40"/>
         <source>Advanced</source>
         <translation>Zaawansowane</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="87"/>
+        <location filename="../src/core/ui/configwidget.ui" line="45"/>
         <source>System tray</source>
         <translation>Zasobnik systemowy</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="92"/>
+        <location filename="../src/core/ui/configwidget.ui" line="50"/>
         <source>Shortcuts</source>
         <translation>Skróty</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="116"/>
+        <location filename="../src/core/ui/configwidget.ui" line="74"/>
         <source>Default save directory</source>
         <translation>Domyślny katalog zapisu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="122"/>
+        <location filename="../src/core/ui/configwidget.ui" line="80"/>
         <source>Path to default selection dir for saving</source>
         <translation>Ścieżka domyślnego zapytania o miejsce zapisu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="135"/>
+        <location filename="../src/core/ui/configwidget.ui" line="93"/>
         <source>Browse filesystem</source>
         <translation>Przeglądaj system plików</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="138"/>
+        <location filename="../src/core/ui/configwidget.ui" line="96"/>
         <source>Browse</source>
         <translation>Przeglądaj</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="148"/>
+        <location filename="../src/core/ui/configwidget.ui" line="106"/>
         <source>Default file</source>
         <translation>Domyślny plik</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="161"/>
+        <location filename="../src/core/ui/configwidget.ui" line="119"/>
         <source>Name:</source>
         <translation>Nazwa:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="168"/>
+        <location filename="../src/core/ui/configwidget.ui" line="126"/>
         <source>Default filename</source>
         <translation>Domyślna nazwa pliku</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="179"/>
+        <location filename="../src/core/ui/configwidget.ui" line="137"/>
         <source>Format</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="192"/>
+        <location filename="../src/core/ui/configwidget.ui" line="150"/>
         <source>Default saving image format</source>
         <translation>Domyślny format zapisywania obrazów</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="211"/>
+        <location filename="../src/core/ui/configwidget.ui" line="169"/>
         <source>Copy file name to the clipboard when saving</source>
         <translation>Kopiuj nazwę pliku do schowka po zapisaniu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="225"/>
+        <location filename="../src/core/ui/configwidget.ui" line="183"/>
         <source>Do not copy</source>
         <translation>Nie kopiuj</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="230"/>
+        <location filename="../src/core/ui/configwidget.ui" line="188"/>
         <source>Copy file name only</source>
         <translation>Kopiuj tylko nazwę pliku</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="235"/>
+        <location filename="../src/core/ui/configwidget.ui" line="193"/>
         <source>Copy full file path</source>
         <translation>Kopiuj pełną ścieżkę do pliku</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="245"/>
+        <location filename="../src/core/ui/configwidget.ui" line="203"/>
         <source>Image quality</source>
         <translation>Jakość obrazów</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="251"/>
+        <location filename="../src/core/ui/configwidget.ui" line="209"/>
         <source>Image quality (1 - small file, 100 - high quality)</source>
         <translation>Jakość obrazu (1 — mały plik, 100 — wysoka jakość)</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="316"/>
+        <location filename="../src/core/ui/configwidget.ui" line="274"/>
         <source>Inserting current date time into saved filename</source>
         <translation>Wstawianie obecnej daty do nazwy zapisywanego pliku</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="319"/>
+        <location filename="../src/core/ui/configwidget.ui" line="277"/>
         <source>Insert current date and time in file name</source>
         <translation>Wstawiaj datę i godzinę w nazwę plików</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="328"/>
+        <location filename="../src/core/ui/configwidget.ui" line="286"/>
         <source>Template: </source>
         <translation>Szablon: </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="353"/>
+        <location filename="../src/core/ui/configwidget.ui" line="311"/>
         <source>Example: </source>
         <translation>Przykład: </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="363"/>
+        <location filename="../src/core/ui/configwidget.ui" line="321"/>
         <source>Automatically saving screenshots in grabbing process</source>
         <translation>Automatyczny zapis zrzutów ekranu w procesie przechwytywania</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="366"/>
+        <location filename="../src/core/ui/configwidget.ui" line="324"/>
         <source>Autosave screenshot</source>
         <translation>Automatycznie zapisuj zrzut ekranu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="378"/>
+        <location filename="../src/core/ui/configwidget.ui" line="336"/>
         <source>Save first screenshot</source>
         <translation>Zapisz pierwszy zrzut ekranu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="387"/>
+        <location filename="../src/core/ui/configwidget.ui" line="345"/>
         <source>Allow run multiplies copy of ScreenGrab</source>
         <translation>Pozwól na uruchamianie wielu kopii ScreenGrab</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="390"/>
+        <location filename="../src/core/ui/configwidget.ui" line="348"/>
         <source>Allow multiple instances of ScreenGrab</source>
         <translation>Pozwól na wiele instancji ScreenGrab</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="397"/>
+        <location filename="../src/core/ui/configwidget.ui" line="355"/>
         <source>Open in external viewer on double click</source>
         <translation>Otwieraj zewnętrzny podgląd dwukrotnym kliknięciem</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="400"/>
+        <location filename="../src/core/ui/configwidget.ui" line="358"/>
         <source>Enable external viewer</source>
         <translation>Włącz zewnętrzną przeglądarkę</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="407"/>
+        <location filename="../src/core/ui/configwidget.ui" line="365"/>
         <source>If this is unchecked, the selected area
 might become larger to fit to outer edges</source>
         <translation>Jeśli nie wybrano, zaznaczony obszar
 może zostać powiększony, aby wypełnić do zewnętrznych krawędzi</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="411"/>
+        <location filename="../src/core/ui/configwidget.ui" line="369"/>
         <source>Fit to edges inside selected area by right clicking</source>
         <translation>Dopasuj do krawędzi wewnątrz zaznaczonego obszaru naciskając prawy przycisk myszy</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="418"/>
+        <location filename="../src/core/ui/configwidget.ui" line="376"/>
+        <source>With multiple screens</source>
+        <translation>Z wieloma ekranami</translation>
+    </message>
+    <message>
+        <location filename="../src/core/ui/configwidget.ui" line="379"/>
+        <source>Remember last selected screen in next session</source>
+        <translation>Zapamiętaj ostatnio wybrany ekran w następnej sesji</translation>
+    </message>
+    <message>
+        <location filename="../src/core/ui/configwidget.ui" line="386"/>
         <source>Notify on saving and copying</source>
         <translation>Powiadamiaj o zapisywaniu i kopiowaniu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="427"/>
+        <location filename="../src/core/ui/configwidget.ui" line="395"/>
         <source>Duration:</source>
         <translation>Długość:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="494"/>
+        <location filename="../src/core/ui/configwidget.ui" line="462"/>
         <source>Show ScreenGrab in the system tray</source>
         <translation>Pokazuj ScreenGrab w zasobniku systemowym</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="434"/>
+        <location filename="../src/core/ui/configwidget.ui" line="402"/>
         <source> sec</source>
         <translation> s</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="501"/>
+        <location filename="../src/core/ui/configwidget.ui" line="469"/>
         <source>Minimize to tray on click close button</source>
         <translation>Minimalizuj do zasobnika po zamknięciu okna</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="504"/>
+        <location filename="../src/core/ui/configwidget.ui" line="472"/>
         <source>Minimize to tray when closing</source>
         <translation>Minimalizuj do zasobnika przy zamykaniu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="543"/>
+        <location filename="../src/core/ui/configwidget.ui" line="511"/>
         <source>Action</source>
         <translation>Działanie</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="548"/>
+        <location filename="../src/core/ui/configwidget.ui" line="516"/>
         <source>Shortcut</source>
         <translation>Skrót</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="553"/>
+        <location filename="../src/core/ui/configwidget.ui" line="521"/>
         <source>New screen</source>
         <translation>Nowy zrzut ekranu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="558"/>
+        <location filename="../src/core/ui/configwidget.ui" line="526"/>
         <source>Save screen</source>
         <translation>Zapisz zrzut ekranu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="563"/>
+        <location filename="../src/core/ui/configwidget.ui" line="531"/>
         <source>Copy screen</source>
         <translation>Kopiuj zrzut ekranu</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="573"/>
-        <source>Help</source>
-        <translation>Pomoc</translation>
-    </message>
-    <message>
-        <location filename="../src/core/ui/configwidget.ui" line="578"/>
+        <location filename="../src/core/ui/configwidget.ui" line="541"/>
         <source>Quit</source>
         <translation>Wyjdź</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="588"/>
+        <location filename="../src/core/ui/configwidget.ui" line="551"/>
         <source>Selected shortcut:</source>
         <translation>Wybrany skrót:</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/configwidget.ui" line="595"/>
+        <location filename="../src/core/ui/configwidget.ui" line="558"/>
         <source>Not defined</source>
         <translation>Nie zdefiniowano</translation>
     </message>
